/* simple control program for philips tv1000 tv card */

#include "tv1000.h"

FILE * exec_filefd;
char home_dir[512];

extern int tv1000_volume;
extern int tv1000_bass;
extern int tv1000_treble;
extern int tv1000_saturation;
extern int tv1000_brightness;
extern int tv1000_contrast;
extern int tv1000_channel;
extern int tv1000_mute;
extern int tv1000_external;
extern int tv1000_external_direct;
extern int tv1000_fine_tune;
int d_frequency = 67.5;


helppri()/*print help menu*/
{
FILE *helpfile;
int a, c, lines;
char path_filename[512];

sprintf(path_filename, "%s/.tv1000/%s", home_dir, "tvhelp.asc");
helpfile = fopen(path_filename, "r");
if(! helpfile)
	{
	fprintf(stdout, "\nCannot open file %s", path_filename);
	return(0);
	}
lines = 0;
while(1)
	{
	c = getc(helpfile);
	if(c == EOF) break;
	fprintf(stdout, "%c", c);
	if(c == '\n') lines++;
	if(lines == 22)
		{
		lines = 0;
		fprintf(stdout, "\nEnter for more \n");
		/* read a user key */	
		system("stty raw");
		c = getc(stdin);
		system("stty sane");
		if(c == 27)break;/* ESCAPE exits */
		fprintf(stdout, "\n");
		}
	}
fclose(helpfile);
return(1);
}


main(int argc, char **argv)
{
int a, b, c, i;
char temp[512];
int audio_volume;
struct passwd *userinfo;
int mode;
double da;
int exit_flag;

/*defaults set here*/
audio_volume = 80;
/*end defaults setting*/

fprintf(stdout,\
"\nPanteltje (c) tv1000-%s PCTV1000 control program  1996-2002\n\n",\
VERSION);

fprintf(stdout,\
"type h for help, ESC exits,\n\
start with tv1000 -h for a list of command line options.\n");

/* get user info */
userinfo = getpwuid(getuid() );

/* get home directory */
sprintf(home_dir, "%s", userinfo -> pw_dir);

iopl(3);

tv1000_ini();

tv1000_volume = 31;

/* load defaults */
sprintf(temp, "defaults");
if( tv1000_load_preferences_from_file(temp) )
	{
	fprintf(stdout, "preferences %s loaded\n", temp);
	}
else/* error report in tv1000_load_preferences */
	{
	fprintf(stdout, "Could not open file %s\n", temp);
	}

exit_flag = 0;
while(1)
	{
	a = getopt(argc, argv, "b:c:def:hi:k:l:o:p:s:t:v:");
	if(a == -1) break;
	switch(a)
		{
		case 'b':
			tv1000_bass = atoi(optarg);
			tv1000_set_bass(tv1000_bass);
			break;
		case 'c':
			tv1000_channel = atoi(optarg);
			tv1000_set_channel(tv1000_channel);
			break;
        case 'd':
			debug_flag = 1;
			break;
		case 'e':
			exit_flag = 1;
			break;
		case 'f':
			da = atof(optarg) * 10.0;
			tv1000_set_frequency( (int)da );			
			break;
		case 'h':
			printf(\
"Usage:\n\
tv1000 [-b bass] [-c channel] [-d] [-e] [-f frequency] [-h] [-i input]\n\
[-k contrast] [-l luminance] [-o output] [-p config_filename]\n\
[-s saturation] [-t treble] [-v volume]\n
\t-b  bass (0 - 100).\n\
\t-c  channel (0 is AUX, else entry in ~/.xcha/defaults is used).\n\
\t-d  print debug messages (o.a. function calls and arguments).\n\
\t-e  exit mode (use if calling from script).\n\
\t-f  frequency (MHz).\n\
\t-h  help (this help).\n\
\t-i  input (0 is AUX, 1 is TV tuner).\n\
\t-k  contrast (0 - 100).\n\
\t-l  luminance (0 -100) (is brightness).\n\
\t-o  output (0 is computer, 1 is TV).\n\
\t-p  filename configuration file (default 'defaults').\n\
\t-s  saturation (0 - 100).\n\
\t-t  treble (0 - 100).\n\
\t-v  volume (0 - 100) internal card volume).\n\
");
			exit(0);	
			break;
		case 'i':
			a = atoi(optarg);
			tv1000_set_input(a);
			break;
		case 'k':
			tv1000_contrast = atoi(optarg);
			tv1000_set_contrast(tv1000_contrast);
			break;
		case 'l':
			tv1000_brightness = atoi(optarg);
			tv1000_set_brightness(tv1000_brightness);
			break;
		case 'o':
			mode = atoi(optarg);
			tv1000_set_screen(mode);
			break;
		case 'p':
			if(! tv1000_load_preferences_from_file(optarg) )
				{
				printf("Could not load preferences file %s\n", optarg);
				}
			break;	
		case 's':
			tv1000_saturation = atoi(optarg);
			tv1000_set_saturation(tv1000_saturation);
			break;
		case 't':
			tv1000_treble = atoi(optarg);
			tv1000_set_treble(tv1000_treble);
			break;
		case 'v':
			tv1000_volume = atoi(optarg);
			tv1000_set_volume(tv1000_volume, 3);/* left + right */
			break;
		case '?':
			if (isprint(optopt) )
 				{
 				fprintf(stdout, "Unknown option `-%c'.\n", optopt);
 				}
			else
				{
				fprintf(stdout, "Unknown option character `\\x%x'.\n",\
				optopt);
				}
			exit(1);
			break;			
		default:
			break;
		}/* end switch a */
	}/* end while getopt() */

if(exit_flag)
	{
	printf("Processing command line arguments completed, returning\n");

	exit(0);
	}

tv1000_set_volume(tv1000_volume, 3);/* left + right */

while(1)
	{
	/* read a user key */	
	system("stty raw");
	c = getc(stdin);
	system("stty sane");
	printf("\n");
	switch(c)
		{
		case 'h':
			helppri();
			break;
		case 'q':
		case 27: /* ESCAPE exits */
			break;
		case '1': /* select computer */
			tv1000_set_screen(0);
			break;
		case '2': /* select tv program */
			tv1000_set_screen(1);
			break;
		case 'v':
		case '4': /* internal volume dtv1000 down */
			if(tv1000_volume > 0) tv1000_volume--;
			tv1000_set_volume(tv1000_volume, 3);/* left + right */
			break;			
		case 'V':
		case '5': /* internal volume dtv1000 down */
			if(tv1000_volume < 31) tv1000_volume++;
			tv1000_set_volume(tv1000_volume, 3);/* left + right */
			break;			
		case '-':/* volume down */
			if(audio_volume > 0) audio_volume--;
			sprintf(temp, "cmix vol %d", audio_volume);
			exec_filefd = popen(temp, "r");
			pclose(exec_filefd);
			if(! exec_filefd) break;
			break;
		case '+':/* volume up */
			if(audio_volume < 100) audio_volume++;
			sprintf(temp, "cmix vol %d", audio_volume);
			exec_filefd = popen(temp, "r");
			if(! exec_filefd) break;
			pclose(exec_filefd);
			break;	
		case '`':/* audio mute toggle */
			tv1000_mute ^= 1;
			tv1000_set_mute(tv1000_mute);			
			break;
		case 'b':/* bass down */
			if(tv1000_bass > 0) tv1000_bass--;
			tv1000_set_bass(tv1000_bass);
			break;
		case 'B':/* bass up */
			if(tv1000_bass < 15) tv1000_bass++;
			tv1000_set_bass(tv1000_bass);
			break;
		case 't':/* treble down */
			if(tv1000_treble > 0) tv1000_treble--;
			tv1000_set_treble(tv1000_treble);
			break;
		case 'T':/* treble up */
			if(tv1000_treble < 15) tv1000_treble++;
			tv1000_set_treble(tv1000_treble);
			break;
		case 's':/* saturation down */
			if(tv1000_saturation > 0) tv1000_saturation--;
			tv1000_set_saturation(tv1000_saturation);
			break;
		case 'S':/* saturation up */
			if(tv1000_saturation < 63) tv1000_saturation++;
			tv1000_set_saturation(tv1000_saturation);
			break;
		case 'l':/* brightness down */
			if(tv1000_brightness > 0) tv1000_brightness--;
			tv1000_set_brightness(tv1000_brightness);
			break;
		case 'L':/* brightness up */
			if(tv1000_brightness < 63) tv1000_brightness++;
			tv1000_set_brightness(tv1000_brightness);
			break;
		case 'c':/* contrast down */
			if(tv1000_contrast > 0) tv1000_contrast--;
			tv1000_set_contrast(tv1000_contrast);
			break;
		case 'C':/* contrast up */
			if(tv1000_contrast < 63) tv1000_contrast++;
			tv1000_set_contrast(tv1000_contrast);
			break;
		case 'P':/* preset vt1000 saturation, brightness, contrast,
				/* bass, treble, volume */
			tv1000_ini();
			break;
		case 'j':
			if(d_frequency > 5) d_frequency -= 5;
			tv1000_set_frequency(d_frequency);
			break;
		case 'J':
			d_frequency += 5;
			tv1000_set_frequency(d_frequency);
			break;
		case 'f':/* load preferences from file */
			fprintf(stdout, "\nLOAD preferences filename? ");
			fscanf(stdin, "%s", temp);
			if( tv1000_load_preferences_from_file(temp) )
				{
				fprintf(stdout, "\npreferences loaded");
				}
			else/* error report in tv1000_load_preferences */
				{
				}
			break;
		case 'F':/* save preferences to file */
			fprintf(stdout, "\nSAVE preferences as? ");
			fscanf(stdin, "%s", temp);
			if( tv1000_save_preferences_to_file(temp) )
				{
				fprintf(stdout, "\npreferences saved");
				}
			else/* error report in tv1000_save_preferences */
				{
				}
			break;
		case 'i':/* internal (TV)*/
			tv1000_external = 0;
			tv1000_set_input(tv1000_external);
			break;
		case 'e':/* external (VCR)*/
			tv1000_external = 1;
			tv1000_set_input(tv1000_external);
			break;
		case 'd':/* channel down */
			if(tv1000_channel > 0) tv1000_channel--; 
			tv1000_set_channel(tv1000_channel);
			break;
		case 'D':/* channel up */
			if(tv1000_channel < 63) tv1000_channel++;
			tv1000_set_channel(tv1000_channel);
			break;	 	
		case '~':/*shifted ''', channel 0 */
			tv1000_channel = 0;
			tv1000_set_channel(tv1000_channel);	
			break;
		case '!':/* shifted 1, channel 1 */
			tv1000_channel = 1;
			tv1000_set_channel(tv1000_channel);
			break;
		case '@': /* shifted 2, channel 2 */
			tv1000_channel = 2;
			tv1000_set_channel(tv1000_channel);
			break;
		case '#':/* shifted 3, channel 3 */
			tv1000_channel = 3;
			tv1000_set_channel(tv1000_channel);
			break;
		case '$':/* shifted 4, channel 4 */
			tv1000_channel = 4;
			tv1000_set_channel(tv1000_channel);
			break;
		case '%':/* shifted 5, channel 5 */
			tv1000_channel = 5;
			tv1000_set_channel(tv1000_channel);
			break;
		case '^':
			tv1000_channel = 6;
			tv1000_set_channel(tv1000_channel);
			break;
		case '&':
			tv1000_channel = 7;
			tv1000_set_channel(tv1000_channel);
			break;
		case '*':
			tv1000_channel = 8;
			tv1000_set_channel(tv1000_channel);
			break;
		case '(':
			tv1000_channel =9;
			tv1000_set_channel(tv1000_channel);
			break;
		case ')':
			tv1000_channel = 10;
			tv1000_set_channel(tv1000_channel);
			break;
		case 'r':
			tv1000_fine_tune = 0;
			tv1000_set_fine_tune(tv1000_fine_tune);
			break;
		case 'x':
			if(tv1000_fine_tune > -1000) tv1000_fine_tune--;
			tv1000_set_fine_tune(tv1000_fine_tune);
			break;
		case 'X':
			if(tv1000_fine_tune < 1000) tv1000_fine_tune++;
			tv1000_set_fine_tune(tv1000_fine_tune);
			break;
		case 'y':
			tv1000_external_direct = 0;
			break;
		case 'Y':
			tv1000_external_direct = 1;
			break;	
		case 'z':
			tv1000_set_reg(0);
			break;
		case 'Z':
			tv1000_set_reg(1);	
			break;
		}/* end switch key value */

	if(c == 27) break;/* ESCAPE */
	if(c == 'q') break;
	}/* end while key input */

exit(1);
}/* end main */
